@@ -1,7 +1,7 @@
 import os
 import sys
 
-from requests import get
+from importlib import resources
 from zipfile import ZipFile
 
 
@@ -26,7 +26,9 @@ def download_lato_font(verbose=False):
     if verbose:
         print("... extracting lato.zip contents to mpl-data/fonts ...")
 
-    with ZipFile("fonts/lato.zip", "r") as zip:
+    font_file = resources.path("apol_dataviz", "fonts/lato.zip")
+
+    with ZipFile(font_file, "r") as zip:
         zip.extractall(mpl_fonts)
 
     if verbose:
